@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.3 2001/11/25 15:55:52 joern Exp $
+# $Id: Config.pm,v 1.4 2001/12/09 00:16:24 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001 Jrn Reder <joern@zyn.de> All Rights Reserved
@@ -27,6 +27,7 @@ sub last_saved_data		{ shift->{last_saved_data}		}
 
 sub set_filename		{ shift->{filename}		= $_[1] }
 sub set_last_saved_data		{ shift->{last_saved_data}	= $_[1] }
+sub set_presets			{ shift->{presets}		= $_[1] }
 
 sub new {
 	my $type = shift;
@@ -45,7 +46,7 @@ sub new {
 			main_window_height => {
 				label => "Startup Window Height",
 				type  => 'number',
-				value => 615,
+				value => 650,
 			},
 			thumbnail_factor => {
 				type  => 'number',
@@ -85,6 +86,7 @@ sub new {
 				tc_clip2_bottom	=> 0,
 				tc_clip2_left	=> 0,
 				tc_clip2_right	=> 0,
+				tc_fast_resize  => 0,
 			),
 			Video::DVDRip::Preset->new (
 				name => "169anamorph",
@@ -99,6 +101,7 @@ sub new {
 				tc_clip2_bottom	=> 0,
 				tc_clip2_left	=> 0,
 				tc_clip2_right	=> 0,
+				tc_fast_resize  => 0,
 			),
 			Video::DVDRip::Preset->new (
 				name => "169anamorph_letter",
@@ -113,6 +116,7 @@ sub new {
 				tc_clip2_bottom	=> 56,
 				tc_clip2_left	=> 64,
 				tc_clip2_right	=> 64,
+				tc_fast_resize  => 0,
 			),
 			Video::DVDRip::Preset->new (
 				name => "43nothing",
@@ -127,6 +131,7 @@ sub new {
 				tc_clip2_bottom	=> 0,
 				tc_clip2_left	=> 0,
 				tc_clip2_right	=> 0,
+				tc_fast_resize  => 0,
 			),
 			Video::DVDRip::Preset->new (
 				name => "43letter_clip",
@@ -141,6 +146,37 @@ sub new {
 				tc_clip2_bottom	=> 0,
 				tc_clip2_left	=> 0,
 				tc_clip2_right	=> 0,
+				tc_fast_resize  => 0,
+			),
+			Video::DVDRip::Preset->new (
+				name => "169anamorph_fast",
+				title => "16:9 Anam. Enc., No Letterbox, Fast Resize",
+				tc_clip1_top	=> 0,
+				tc_clip1_bottom	=> 0,
+				tc_clip1_left	=> 8,
+				tc_clip1_right	=> 8,
+				tc_zoom_width	=> 704,
+				tc_zoom_height	=> 416,
+				tc_clip2_top	=> 0,
+				tc_clip2_bottom	=> 0,
+				tc_clip2_left	=> 0,
+				tc_clip2_right	=> 0,
+				tc_fast_resize  => 0,
+			),
+			Video::DVDRip::Preset->new (
+				name => "169anamorph_letter_fast",
+				title => "16:9 Anam. Enc., Letterbox, Fast Resize",
+				tc_clip1_top	=> 64,
+				tc_clip1_bottom	=> 64,
+				tc_clip1_left	=> 40,
+				tc_clip1_right	=> 40,
+				tc_zoom_width	=> 640,
+				tc_zoom_height	=> 320,
+				tc_clip2_top	=> 0,
+				tc_clip2_bottom	=> 0,
+				tc_clip2_left	=> 0,
+				tc_clip2_right	=> 0,
+				tc_fast_resize  => 1,
 			),
 		],
 	};
@@ -159,8 +195,14 @@ sub load {
 	$config = do $filename;
 	confess "can't load $filename. Perl error: $@" if $@;
 
+	my $presets = $self->presets;
+
 	%{$self} = %{$config};
 	
+	# actually we overide presets, since no user editable
+	# presets exist
+	$self->set_presets ($presets);
+	
 	1;
 }
 
@@ -190,7 +232,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or confess "can't write $filename";
-	print $fh q{# $Id: Config.pm,v 1.3 2001/11/25 15:55:52 joern Exp $},"\n";
+	print $fh q{# $Id: Config.pm,v 1.4 2001/12/09 00:16:24 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
